Class: Google::Iam::V3beta::AccessPolicies::Rest::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/iam/v3beta/access_policies/rest/client.rb

Overview

REST client for the AccessPolicies service.

Manages Identity and Access Management (IAM) access policies.

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#access_policy_path, #folder_location_path, #location_path, #organization_location_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new AccessPolicies REST client object.

Examples:


# Create a client using the default configuration
client = ::Google::Iam::V3beta::AccessPolicies::Rest::Client.new

# Create a client using a custom configuration
client = ::Google::Iam::V3beta::AccessPolicies::Rest::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the AccessPolicies client.

Yield Parameters:



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 147

def initialize
  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end

  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @operations_client = ::Google::Iam::V3beta::AccessPolicies::Rest::Operations.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @config.endpoint
    config.universe_domain = @config.universe_domain
  end

  @access_policies_stub = ::Google::Iam::V3beta::AccessPolicies::Rest::ServiceStub.new(
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    credentials: credentials,
    logger: @config.logger
  )

  @access_policies_stub.logger(stub: true)&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @access_policies_stub.endpoint
    config.universe_domain = @access_policies_stub.universe_domain
    config.logger = @access_policies_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#location_clientGoogle::Cloud::Location::Locations::Rest::Client (readonly)

Get the associated client for mix-in of the Locations.

Returns:

  • (Google::Cloud::Location::Locations::Rest::Client)


216
217
218
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 216

def location_client
  @location_client
end

#operations_client::Google::Iam::V3beta::AccessPolicies::Rest::Operations (readonly)

Get the associated client for long-running operations.



209
210
211
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 209

def operations_client
  @operations_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the AccessPolicies Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all AccessPolicies clients
::Google::Iam::V3beta::AccessPolicies::Rest::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 64

def self.configure
  @configure ||= begin
    namespace = ["Google", "Iam", "V3beta"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.create_access_policy.timeout = 30.0

    default_config.rpcs.get_access_policy.timeout = 60.0
    default_config.rpcs.get_access_policy.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.update_access_policy.timeout = 30.0

    default_config.rpcs.delete_access_policy.timeout = 30.0

    default_config.rpcs.list_access_policies.timeout = 60.0
    default_config.rpcs.list_access_policies.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config.rpcs.search_access_policy_bindings.timeout = 60.0
    default_config.rpcs.search_access_policy_bindings.retry_policy = {
      initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the AccessPolicies Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



117
118
119
120
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 117

def configure
  yield @config if block_given?
  @config
end

#create_access_policy(request, options = nil) ⇒ ::Gapic::Operation #create_access_policy(parent: nil, access_policy_id: nil, access_policy: nil, validate_only: nil) ⇒ ::Gapic::Operation

Creates an access policy, and returns a long running operation.

Examples:

Basic example

require "google/iam/v3beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Iam::V3beta::AccessPolicies::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Iam::V3beta::CreateAccessPolicyRequest.new

# Call the create_access_policy method.
result = client.create_access_policy request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #create_access_policy(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to create_access_policy via a request object, either of type CreateAccessPolicyRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Iam::V3beta::CreateAccessPolicyRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #create_access_policy(parent: nil, access_policy_id: nil, access_policy: nil, validate_only: nil) ⇒ ::Gapic::Operation

    Pass arguments to create_access_policy via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource where this access policy will be created.

      Format: projects/{project_id}/locations/{location} projects/{project_number}/locations/{location} folders/{folder_id}/locations/{location} organizations/{organization_id}/locations/{location}

    • access_policy_id (::String) (defaults to: nil)

      Required. The ID to use for the access policy, which will become the final component of the access policy's resource name.

      This value must start with a lowercase letter followed by up to 62 lowercase letters, numbers, hyphens, or dots. Pattern, /[a-z][a-z0-9-.]{2,62}/.

      This value must be unique among all access policies with the same parent.

    • access_policy (::Google::Iam::V3beta::AccessPolicy, ::Hash) (defaults to: nil)

      Required. The access policy to create.

    • validate_only (::Boolean) (defaults to: nil)

      Optional. If set, validate the request and preview the creation, but do not actually post it.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 300

def create_access_policy request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Iam::V3beta::CreateAccessPolicyRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_access_policy..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Iam::V3beta::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.create_access_policy.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_access_policy.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @access_policies_stub.create_access_policy request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_access_policy(request, options = nil) ⇒ ::Gapic::Operation #delete_access_policy(name: nil, etag: nil, validate_only: nil, force: nil) ⇒ ::Gapic::Operation

Deletes an access policy.

Examples:

Basic example

require "google/iam/v3beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Iam::V3beta::AccessPolicies::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Iam::V3beta::DeleteAccessPolicyRequest.new

# Call the delete_access_policy method.
result = client.delete_access_policy request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #delete_access_policy(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to delete_access_policy via a request object, either of type DeleteAccessPolicyRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Iam::V3beta::DeleteAccessPolicyRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #delete_access_policy(name: nil, etag: nil, validate_only: nil, force: nil) ⇒ ::Gapic::Operation

    Pass arguments to delete_access_policy via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the access policy to delete.

      Format: projects/{project_id}/locations/{location}/accessPolicies/{access_policy_id} projects/{project_number}/locations/{location}/accessPolicies/{access_policy_id} folders/{folder_id}/locations/{location}/accessPolicies/{access_policy_id} organizations/{organization_id}/locations/{location}/accessPolicies/{access_policy_id}

    • etag (::String) (defaults to: nil)

      Optional. The etag of the access policy. If this is provided, it must match the server's etag.

    • validate_only (::Boolean) (defaults to: nil)

      Optional. If set, validate the request and preview the deletion, but do not actually post it.

    • force (::Boolean) (defaults to: nil)

      Optional. If set to true, the request will force the deletion of the Policy even if the Policy references PolicyBindings.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 579

def delete_access_policy request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Iam::V3beta::DeleteAccessPolicyRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_access_policy..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Iam::V3beta::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.delete_access_policy.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_access_policy.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @access_policies_stub.delete_access_policy request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_access_policy(request, options = nil) ⇒ ::Google::Iam::V3beta::AccessPolicy #get_access_policy(name: nil) ⇒ ::Google::Iam::V3beta::AccessPolicy

Gets an access policy.

Examples:

Basic example

require "google/iam/v3beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Iam::V3beta::AccessPolicies::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Iam::V3beta::GetAccessPolicyRequest.new

# Call the get_access_policy method.
result = client.get_access_policy request

# The returned object is of type Google::Iam::V3beta::AccessPolicy.
p result

Overloads:

  • #get_access_policy(request, options = nil) ⇒ ::Google::Iam::V3beta::AccessPolicy

    Pass arguments to get_access_policy via a request object, either of type GetAccessPolicyRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Iam::V3beta::GetAccessPolicyRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #get_access_policy(name: nil) ⇒ ::Google::Iam::V3beta::AccessPolicy

    Pass arguments to get_access_policy via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the access policy to retrieve.

      Format: projects/{project_id}/locations/{location}/accessPolicies/{access_policy_id} projects/{project_number}/locations/{location}/accessPolicies/{access_policy_id} folders/{folder_id}/locations/{location}/accessPolicies/{access_policy_id} organizations/{organization_id}/locations/{location}/accessPolicies/{access_policy_id}

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 386

def get_access_policy request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Iam::V3beta::GetAccessPolicyRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_access_policy..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Iam::V3beta::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.get_access_policy.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_access_policy.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @access_policies_stub.get_access_policy request, options do |result, operation|
    yield result, operation if block_given?
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_access_policies(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Iam::V3beta::AccessPolicy> #list_access_policies(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Iam::V3beta::AccessPolicy>

Lists access policies.

Examples:

Basic example

require "google/iam/v3beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Iam::V3beta::AccessPolicies::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Iam::V3beta::ListAccessPoliciesRequest.new

# Call the list_access_policies method.
result = client.list_access_policies request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Iam::V3beta::AccessPolicy.
  p item
end

Overloads:

  • #list_access_policies(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Iam::V3beta::AccessPolicy>

    Pass arguments to list_access_policies via a request object, either of type ListAccessPoliciesRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Iam::V3beta::ListAccessPoliciesRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #list_access_policies(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Iam::V3beta::AccessPolicy>

    Pass arguments to list_access_policies via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent resource, which owns the collection of access policy resources.

      Format: projects/{project_id}/locations/{location} projects/{project_number}/locations/{location} folders/{folder_id}/locations/{location} organizations/{organization_id}/locations/{location}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of access policies to return. The service may return fewer than this value.

      If unspecified, at most 50 access policies will be returned. Valid value ranges from 1 to 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous ListAccessPolicies call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to ListAccessPolicies must match the call that provided the page token.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 684

def list_access_policies request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Iam::V3beta::ListAccessPoliciesRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_access_policies..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Iam::V3beta::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.list_access_policies.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_access_policies.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @access_policies_stub.list_access_policies request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @access_policies_stub, :list_access_policies, "access_policies", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


223
224
225
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 223

def logger
  @access_policies_stub.logger
end

#search_access_policy_bindings(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Iam::V3beta::PolicyBinding> #search_access_policy_bindings(name: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Iam::V3beta::PolicyBinding>

Returns all policy bindings that bind a specific policy if a user has searchPolicyBindings permission on that policy.

Examples:

Basic example

require "google/iam/v3beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Iam::V3beta::AccessPolicies::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Iam::V3beta::SearchAccessPolicyBindingsRequest.new

# Call the search_access_policy_bindings method.
result = client.search_access_policy_bindings request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Iam::V3beta::PolicyBinding.
  p item
end

Overloads:

  • #search_access_policy_bindings(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Iam::V3beta::PolicyBinding>

    Pass arguments to search_access_policy_bindings via a request object, either of type SearchAccessPolicyBindingsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Iam::V3beta::SearchAccessPolicyBindingsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #search_access_policy_bindings(name: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Iam::V3beta::PolicyBinding>

    Pass arguments to search_access_policy_bindings via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the access policy. Format: organizations/{organization_id}/locations/{location}/accessPolicies/{access_policy_id} folders/{folder_id}/locations/{location}/accessPolicies/{access_policy_id} projects/{project_id}/locations/{location}/accessPolicies/{access_policy_id} projects/{project_number}/locations/{location}/accessPolicies/{access_policy_id}

    • page_size (::Integer) (defaults to: nil)

      Optional. The maximum number of policy bindings to return. The service may return fewer than this value.

      If unspecified, at most 50 policy bindings will be returned. The maximum value is 1000; values above 1000 will be coerced to 1000.

    • page_token (::String) (defaults to: nil)

      Optional. A page token, received from a previous SearchAccessPolicyBindingsRequest call. Provide this to retrieve the subsequent page.

      When paginating, all other parameters provided to SearchAccessPolicyBindingsRequest must match the call that provided the page token.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 788

def search_access_policy_bindings request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Iam::V3beta::SearchAccessPolicyBindingsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.search_access_policy_bindings..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Iam::V3beta::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.search_access_policy_bindings.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.search_access_policy_bindings.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @access_policies_stub.search_access_policy_bindings request, options do |result, operation|
    result = ::Gapic::Rest::PagedEnumerable.new @access_policies_stub, :search_access_policy_bindings, "policy_bindings", request, result, options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


127
128
129
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 127

def universe_domain
  @access_policies_stub.universe_domain
end

#update_access_policy(request, options = nil) ⇒ ::Gapic::Operation #update_access_policy(access_policy: nil, validate_only: nil) ⇒ ::Gapic::Operation

Updates an access policy.

Examples:

Basic example

require "google/iam/v3beta"

# Create a client object. The client can be reused for multiple calls.
client = Google::Iam::V3beta::AccessPolicies::Rest::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Iam::V3beta::UpdateAccessPolicyRequest.new

# Call the update_access_policy method.
result = client.update_access_policy request

# The returned object is of type Gapic::Operation. You can use it to
# check the status of an operation, cancel it, or wait for results.
# Here is how to wait for a response.
result.wait_until_done! timeout: 60
if result.response?
  p result.response
else
  puts "No response received."
end

Overloads:

  • #update_access_policy(request, options = nil) ⇒ ::Gapic::Operation

    Pass arguments to update_access_policy via a request object, either of type UpdateAccessPolicyRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Iam::V3beta::UpdateAccessPolicyRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries etc. Optional.

  • #update_access_policy(access_policy: nil, validate_only: nil) ⇒ ::Gapic::Operation

    Pass arguments to update_access_policy via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • access_policy (::Google::Iam::V3beta::AccessPolicy, ::Hash) (defaults to: nil)

      Required. The access policy to update.

      The access policy's name field is used to identify the policy to update.

    • validate_only (::Boolean) (defaults to: nil)

      Optional. If set, validate the request and preview the update, but do not actually post it.

Yields:

  • (result, operation)

    Access the result along with the TransportOperation object

Yield Parameters:

  • result (::Gapic::Operation)
  • operation (::Gapic::Rest::TransportOperation)

Returns:

  • (::Gapic::Operation)

Raises:

  • (::Google::Cloud::Error)

    if the REST call is aborted.



477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
# File 'lib/google/iam/v3beta/access_policies/rest/client.rb', line 477

def update_access_policy request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Iam::V3beta::UpdateAccessPolicyRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_access_policy..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Iam::V3beta::VERSION,
    transports_version_send: [:rest]

  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  options.apply_defaults timeout:      @config.rpcs.update_access_policy.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_access_policy.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @access_policies_stub.update_access_policy request, options do |result, operation|
    result = ::Gapic::Operation.new result, @operations_client, options: options
    yield result, operation if block_given?
    throw :response, result
  end
rescue ::Gapic::Rest::Error => e
  raise ::Google::Cloud::Error.from_error(e)
end