Class: Google::Iam::V3beta::AccessPolicy

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/iam/v3beta/access_policy_resources.rb

Overview

An IAM access policy resource.

Defined Under Namespace

Classes: AnnotationsEntry

Instance Attribute Summary collapse

Instance Attribute Details

#annotations::Google::Protobuf::Map{::String => ::String}

Returns Optional. User defined annotations. See https://google.aip.dev/148#annotations for more details such as format and size limitations.

Returns:



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'proto_docs/google/iam/v3beta/access_policy_resources.rb', line 60

class AccessPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#create_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the access policy was created.

Returns:



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'proto_docs/google/iam/v3beta/access_policy_resources.rb', line 60

class AccessPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#details::Google::Iam::V3beta::AccessPolicyDetails

Returns Optional. The details for the access policy.

Returns:



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'proto_docs/google/iam/v3beta/access_policy_resources.rb', line 60

class AccessPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#display_name::String

Returns Optional. The description of the access policy. Must be less than or equal to 63 characters.

Returns:

  • (::String)

    Optional. The description of the access policy. Must be less than or equal to 63 characters.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'proto_docs/google/iam/v3beta/access_policy_resources.rb', line 60

class AccessPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#etag::String

Returns Optional. The etag for the access policy. If this is provided on update, it must match the server's etag.

Returns:

  • (::String)

    Optional. The etag for the access policy. If this is provided on update, it must match the server's etag.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'proto_docs/google/iam/v3beta/access_policy_resources.rb', line 60

class AccessPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#name::String

Returns Identifier. The resource name of the access policy.

The following formats are supported:

  • projects/{project_id}/locations/{location}/accessPolicies/{policy_id}
  • projects/{project_number}/locations/{location}/accessPolicies/{policy_id}
  • folders/{folder_id}/locations/{location}/accessPolicies/{policy_id}
  • organizations/{organization_id}/locations/{location}/accessPolicies/{policy_id}.

Returns:

  • (::String)

    Identifier. The resource name of the access policy.

    The following formats are supported:

    • projects/{project_id}/locations/{location}/accessPolicies/{policy_id}
    • projects/{project_number}/locations/{location}/accessPolicies/{policy_id}
    • folders/{folder_id}/locations/{location}/accessPolicies/{policy_id}
    • organizations/{organization_id}/locations/{location}/accessPolicies/{policy_id}


60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'proto_docs/google/iam/v3beta/access_policy_resources.rb', line 60

class AccessPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#uid::String (readonly)

Returns Output only. The globally unique ID of the access policy.

Returns:

  • (::String)

    Output only. The globally unique ID of the access policy.



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'proto_docs/google/iam/v3beta/access_policy_resources.rb', line 60

class AccessPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#update_time::Google::Protobuf::Timestamp (readonly)

Returns Output only. The time when the access policy was most recently updated.

Returns:



60
61
62
63
64
65
66
67
68
69
70
71
72
# File 'proto_docs/google/iam/v3beta/access_policy_resources.rb', line 60

class AccessPolicy
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # @!attribute [rw] key
  #   @return [::String]
  # @!attribute [rw] value
  #   @return [::String]
  class AnnotationsEntry
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end