Class: Google::Iam::V3beta::AccessPolicyRule::Operation

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/iam/v3beta/access_policy_resources.rb

Overview

Attributes that are used to determine whether this rule applies to a request.

Instance Attribute Summary collapse

Instance Attribute Details

#excluded_permissions::Array<::String>

Returns Optional. Specifies the permissions that this rule excludes from the set of affected permissions given by permissions. If a permission appears in permissions and in excluded_permissions then it will not be subject to the policy effect.

The excluded permissions can be specified using the same syntax as permissions.

Returns:

  • (::Array<::String>)

    Optional. Specifies the permissions that this rule excludes from the set of affected permissions given by permissions. If a permission appears in permissions and in excluded_permissions then it will not be subject to the policy effect.

    The excluded permissions can be specified using the same syntax as permissions.



195
196
197
198
# File 'proto_docs/google/iam/v3beta/access_policy_resources.rb', line 195

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#permissions::Array<::String>

Returns Optional. The permissions that are explicitly affected by this rule. Each permission uses the format {service_fqdn}/{resource}.{verb}, where {service_fqdn} is the fully qualified domain name for the service. Currently supported permissions are as follows:

  • eventarc.googleapis.com/messageBuses.publish.

Returns:

  • (::Array<::String>)

    Optional. The permissions that are explicitly affected by this rule. Each permission uses the format {service_fqdn}/{resource}.{verb}, where {service_fqdn} is the fully qualified domain name for the service. Currently supported permissions are as follows:

    • eventarc.googleapis.com/messageBuses.publish.


195
196
197
198
# File 'proto_docs/google/iam/v3beta/access_policy_resources.rb', line 195

class Operation
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end