Class: Google::Iam::V3beta::CreateAccessPolicyRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/iam/v3beta/access_policies_service.rb

Overview

Request message for CreateAccessPolicy method.

Instance Attribute Summary collapse

Instance Attribute Details

#access_policy::Google::Iam::V3beta::AccessPolicy

Returns Required. The access policy to create.

Returns:



51
52
53
54
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 51

class CreateAccessPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#access_policy_id::String

Returns Required. The ID to use for the access policy, which will become the final component of the access policy's resource name.

This value must start with a lowercase letter followed by up to 62 lowercase letters, numbers, hyphens, or dots. Pattern, /[a-z][a-z0-9-.]{2,62}/.

This value must be unique among all access policies with the same parent.

Returns:

  • (::String)

    Required. The ID to use for the access policy, which will become the final component of the access policy's resource name.

    This value must start with a lowercase letter followed by up to 62 lowercase letters, numbers, hyphens, or dots. Pattern, /[a-z][a-z0-9-.]{2,62}/.

    This value must be unique among all access policies with the same parent.



51
52
53
54
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 51

class CreateAccessPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this access policy will be created.

Format: projects/{project_id}/locations/{location} projects/{project_number}/locations/{location} folders/{folder_id}/locations/{location} organizations/{organization_id}/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource where this access policy will be created.

    Format: projects/{project_id}/locations/{location} projects/{project_number}/locations/{location} folders/{folder_id}/locations/{location} organizations/{organization_id}/locations/{location}



51
52
53
54
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 51

class CreateAccessPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. If set, validate the request and preview the creation, but do not actually post it.

Returns:

  • (::Boolean)

    Optional. If set, validate the request and preview the creation, but do not actually post it.



51
52
53
54
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 51

class CreateAccessPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end