Class: Google::Iam::V3beta::ListAccessPoliciesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/iam/v3beta/access_policies_service.rb

Overview

Request message for ListAccessPolicies method.

Instance Attribute Summary collapse

Instance Attribute Details

#page_size::Integer

Returns Optional. The maximum number of access policies to return. The service may return fewer than this value.

If unspecified, at most 50 access policies will be returned. Valid value ranges from 1 to 1000; values above 1000 will be coerced to 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of access policies to return. The service may return fewer than this value.

    If unspecified, at most 50 access policies will be returned. Valid value ranges from 1 to 1000; values above 1000 will be coerced to 1000.



141
142
143
144
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 141

class ListAccessPoliciesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ListAccessPolicies call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to ListAccessPolicies must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous ListAccessPolicies call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to ListAccessPolicies must match the call that provided the page token.



141
142
143
144
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 141

class ListAccessPoliciesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource, which owns the collection of access policy resources.

Format: projects/{project_id}/locations/{location} projects/{project_number}/locations/{location} folders/{folder_id}/locations/{location} organizations/{organization_id}/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource, which owns the collection of access policy resources.

    Format: projects/{project_id}/locations/{location} projects/{project_number}/locations/{location} folders/{folder_id}/locations/{location} organizations/{organization_id}/locations/{location}



141
142
143
144
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 141

class ListAccessPoliciesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end