Class: Google::Iam::V3beta::ListAccessPoliciesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/iam/v3beta/access_policies_service.rb

Overview

Response message for ListAccessPolicies method.

Instance Attribute Summary collapse

Instance Attribute Details

#access_policies::Array<::Google::Iam::V3beta::AccessPolicy>

Returns The access policies from the specified parent.

Returns:



154
155
156
157
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 154

class ListAccessPoliciesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns Optional. A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    Optional. A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



154
155
156
157
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 154

class ListAccessPoliciesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end