Class: Google::Iam::V3beta::SearchTargetPolicyBindingsRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/iam/v3beta/policy_bindings_service.rb

Overview

Request message for SearchTargetPolicyBindings method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Optional. Filtering currently only supports the kind of policies to return, and must be in the format "policy_kind={policy_kind}".

If String is empty, bindings bound to all kinds of policies would be returned.

The only supported values are the following:

  • "policy_kind=PRINCIPAL_ACCESS_BOUNDARY",
  • "policy_kind=ACCESS"

Returns:

  • (::String)

    Optional. Filtering currently only supports the kind of policies to return, and must be in the format "policy_kind={policy_kind}".

    If String is empty, bindings bound to all kinds of policies would be returned.

    The only supported values are the following:

    • "policy_kind=PRINCIPAL_ACCESS_BOUNDARY",
    • "policy_kind=ACCESS"


224
225
226
227
# File 'proto_docs/google/iam/v3beta/policy_bindings_service.rb', line 224

class SearchTargetPolicyBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Optional. The maximum number of policy bindings to return. The service may return fewer than this value.

The default value is 50. The maximum value is 1000.

Returns:

  • (::Integer)

    Optional. The maximum number of policy bindings to return. The service may return fewer than this value.

    The default value is 50. The maximum value is 1000.



224
225
226
227
# File 'proto_docs/google/iam/v3beta/policy_bindings_service.rb', line 224

class SearchTargetPolicyBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous SearchTargetPolicyBindingsRequest call. Provide this to retrieve the subsequent page.

When paginating, all other parameters provided to SearchTargetPolicyBindingsRequest must match the call that provided the page token.

Returns:

  • (::String)

    Optional. A page token, received from a previous SearchTargetPolicyBindingsRequest call. Provide this to retrieve the subsequent page.

    When paginating, all other parameters provided to SearchTargetPolicyBindingsRequest must match the call that provided the page token.



224
225
226
227
# File 'proto_docs/google/iam/v3beta/policy_bindings_service.rb', line 224

class SearchTargetPolicyBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent resource where this search will be performed. This should be the nearest Resource Manager resource (project, folder, or organization) to the target.

Format:

  • projects/{project_id}/locations/{location}
  • projects/{project_number}/locations/{location}
  • folders/{folder_id}/locations/{location}
  • organizations/{organization_id}/locations/{location}.

Returns:

  • (::String)

    Required. The parent resource where this search will be performed. This should be the nearest Resource Manager resource (project, folder, or organization) to the target.

    Format:

    • projects/{project_id}/locations/{location}
    • projects/{project_number}/locations/{location}
    • folders/{folder_id}/locations/{location}
    • organizations/{organization_id}/locations/{location}


224
225
226
227
# File 'proto_docs/google/iam/v3beta/policy_bindings_service.rb', line 224

class SearchTargetPolicyBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#target::String

Returns Required. The target resource, which is bound to the policy in the binding.

Format:

  • //iam.googleapis.com/locations/global/workforcePools/POOL_ID
  • //iam.googleapis.com/projects/PROJECT_NUMBER/locations/global/workloadIdentityPools/POOL_ID
  • //iam.googleapis.com/locations/global/workspace/WORKSPACE_ID
  • //cloudresourcemanager.googleapis.com/projects/{project_number}
  • //cloudresourcemanager.googleapis.com/folders/{folder_id}
  • //cloudresourcemanager.googleapis.com/organizations/{organization_id}.

Returns:

  • (::String)

    Required. The target resource, which is bound to the policy in the binding.

    Format:

    • //iam.googleapis.com/locations/global/workforcePools/POOL_ID
    • //iam.googleapis.com/projects/PROJECT_NUMBER/locations/global/workloadIdentityPools/POOL_ID
    • //iam.googleapis.com/locations/global/workspace/WORKSPACE_ID
    • //cloudresourcemanager.googleapis.com/projects/{project_number}
    • //cloudresourcemanager.googleapis.com/folders/{folder_id}
    • //cloudresourcemanager.googleapis.com/organizations/{organization_id}


224
225
226
227
# File 'proto_docs/google/iam/v3beta/policy_bindings_service.rb', line 224

class SearchTargetPolicyBindingsRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end