Class: Google::Iam::V3beta::UpdateAccessPolicyRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/iam/v3beta/access_policies_service.rb

Overview

Request message for UpdateAccessPolicy method.

Instance Attribute Summary collapse

Instance Attribute Details

#access_policy::Google::Iam::V3beta::AccessPolicy

Returns Required. The access policy to update.

The access policy's name field is used to identify the policy to update.

Returns:



82
83
84
85
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 82

class UpdateAccessPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#validate_only::Boolean

Returns Optional. If set, validate the request and preview the update, but do not actually post it.

Returns:

  • (::Boolean)

    Optional. If set, validate the request and preview the update, but do not actually post it.



82
83
84
85
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 82

class UpdateAccessPolicyRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end