Module: Google::Iam::V3beta::AccessPolicyRule::Effect
- Defined in:
- proto_docs/google/iam/v3beta/access_policy_resources.rb
Overview
An effect to describe the access relationship.
Constant Summary collapse
- EFFECT_UNSPECIFIED =
The effect is unspecified.
0- DENY =
The policy will deny access if it evaluates to true.
1- ALLOW =
The policy will grant access if it evaluates to true.
2