Class: Google::Iam::V3beta::DeleteAccessPolicyRequest
- Inherits:
-
Object
- Object
- Google::Iam::V3beta::DeleteAccessPolicyRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/iam/v3beta/access_policies_service.rb
Overview
Request message for DeleteAccessPolicy method.
Instance Attribute Summary collapse
-
#etag ⇒ ::String
Optional.
-
#force ⇒ ::Boolean
Optional.
-
#name ⇒ ::String
Required.
-
#validate_only ⇒ ::Boolean
Optional.
Instance Attribute Details
#etag ⇒ ::String
Returns Optional. The etag of the access policy. If this is provided, it must match the server's etag.
109 110 111 112 |
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 109 class DeleteAccessPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#force ⇒ ::Boolean
Returns Optional. If set to true, the request will force the deletion of the Policy even if the Policy references PolicyBindings.
109 110 111 112 |
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 109 class DeleteAccessPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The name of the access policy to delete.
Format:
projects/{project_id}/locations/{location}/accessPolicies/{access_policy_id}
projects/{project_number}/locations/{location}/accessPolicies/{access_policy_id}
folders/{folder_id}/locations/{location}/accessPolicies/{access_policy_id}
organizations/{organization_id}/locations/{location}/accessPolicies/{access_policy_id}.
109 110 111 112 |
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 109 class DeleteAccessPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#validate_only ⇒ ::Boolean
Returns Optional. If set, validate the request and preview the deletion, but do not actually post it.
109 110 111 112 |
# File 'proto_docs/google/iam/v3beta/access_policies_service.rb', line 109 class DeleteAccessPolicyRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |